==> amazcart_v4.0.zip: amazcart_v4.0/resources/lang/default/marketing.php <==
<?php
return [
    'new_user_zone' => 'New User Zone',
    'general_setting' => 'General Setting',
    'product_section' => 'Product Section',
    'exclusive_price_section' => 'Exclusive Price Section',
    'coupon_section' => 'Coupon Section',
    'background_color' => 'Background-Color',
    'text_color' => 'Text-Color',
    'setup_products' => 'Setup Products',
    'navigation_label' => 'Navigation Label',
    'slogan' => 'Slogan',
    'select_products' => 'Select Products',
    'selected_product_list' => 'Selected Product List',
    'select_category' => 'Select Category',
    'selected_category_list' => 'Selected Category List',
    'coupon_section_setup' => 'Coupon Section Setup',
    'coupon_list' => 'Coupon List',
    'create_new_user_zone' => 'Create New User Zone',
    'flash_deal' => 'Flash Deal',
    'update_flash_deal' => 'Update Flash Deal',
    'create_flash_deal' => 'Create Flash Deal',
    'news_letter' => 'News Letter',
    'publish_date' => 'Publish Date',
    'created_by' => 'Created By',
    'mail_to' => 'Mail To',
    'create_news_letter' => 'Create News Letter',
    'update_news_letter' => 'Update News Letter',
    'publish_on' => 'Publish On',
    'send_to' => 'Send To',
    'all_user' => 'All User',
    'role_wise' => 'Role Wise',
    'multiple_role_select_user' => 'Multiple Role Select User',
    'all_subscription' => 'All Subscription',
    'selected_role_user' => 'Selected Role User',
    'save_test_mail' => 'Save & Test Mail',
    'test_mail_has_been_send_successfully' => 'Test Mail has been Send successfully!',
    'test_mail' => 'Test Mail',
    'bulk_sms' => 'Bulk SMS',
    'sms_list' => 'SMS List',
    'sending' => 'Sending',
    'test_sms_has_been_send_successfully' => 'Test SMS has been Send successfully!',
    'message_to' => 'Message To',
    'create_bulk_sms' => 'Create Bulk SMS',
    'update_bulk_sms' => 'Update Bulk SMS',
    'save_test_sms' => 'Save & Test SMS',
    'test_sms' => 'Test SMS',
    'coupon_list' => 'Coupon List',
    'select_coupon_type_first' => 'Select Coupon Type First',
    'product_base' => 'Product Base',
    'order_base' => 'Order Base',
    'free_shipping' => 'Free Shipping',
    'create_coupon' => 'Create Coupon',
    'coupon_type' => 'Coupon Type',
    'add_coupon_for_free_shipping' => 'Add Coupon For Free Shipping',
    'add_coupon_based_on_order' => 'Add Coupon Based on Order',
    'add_coupon_based_on_products' => 'Add Coupon Based on Products',
    'coupon_code' => 'Coupon code',
    'maximum_discount' => 'Maximum Discount',
    'allow_multiple_buy' => 'Allow Multiple Buy',
    'minimum_shopping' => 'Minimum Shopping',
    'referral_code_list' => 'Referral Code List',
    'amount_is_getter_than_maximum_limit' => 'Amount is getter than maximum limit',
    'customer_name' => 'Customer Name',
    'create_date' => 'Create Date',
    'maximum_limit' => 'Maximum Limit',
    'subscriber' => 'Subscriber',
    'subscriber_list' => 'Subscriber List',
    'marketing' => 'Marketing',
    'flash_deals' => 'Flash Deals',
    'coupons' => 'Coupons',
    'subscribers' => 'Subscribers',
    'news_letters' => 'News Letters',
    'referral_code_setup' => 'Referral Code Setup',
    'num_of_uses' => 'Num of uses',
    'total_discount' => 'Total Discount',
    'this_item_already_added_to_list' => 'This item already added to list.',
    'marketing_campaign_planning' => 'Marketing campaign planning',
    'cool_app' => 'Cool App',
    'awesome_app' => 'Awesome App',
    'what_a_cool_app' => 'what a Cool App',
    'marketing setting' => 'marketing setting',
    'Send verify link' => 'Send verify link',
    'Verification link send successfully' => 'Verification link send successfully.',
    'giftcard' => 'Giftcard',
    'multiple_buy_limit' => 'Multiple Buy Limit',
];

==> amazcart_v4.4.zip: amazcart_v4.4/resources/lang/default/marketing.php <==
<?php
return [
    'new_user_zone' => 'New User Zone',
    'general_setting' => 'General Setting',
    'product_section' => 'Product Section',
    'exclusive_price_section' => 'Exclusive Price Section',
    'coupon_section' => 'Coupon Section',
    'background_color' => 'Background-Color',
    'text_color' => 'Text-Color',
    'setup_products' => 'Setup Products',
    'navigation_label' => 'Navigation Label',
    'slogan' => 'Slogan',
    'select_products' => 'Select Products',
    'selected_product_list' => 'Selected Product List',
    'select_category' => 'Select Category',
    'selected_category_list' => 'Selected Category List',
    'coupon_section_setup' => 'Coupon Section Setup',
    'coupon_list' => 'Coupon List',
    'create_new_user_zone' => 'Create New User Zone',
    'flash_deal' => 'Flash Deal',
    'update_flash_deal' => 'Update Flash Deal',
    'create_flash_deal' => 'Create Flash Deal',
    'news_letter' => 'News Letter',
    'publish_date' => 'Publish Date',
    'created_by' => 'Created By',
    'mail_to' => 'Mail To',
    'create_news_letter' => 'Create News Letter',
    'update_news_letter' => 'Update News Letter',
    'publish_on' => 'Publish On',
    'send_to' => 'Send To',
    'all_user' => 'All User',
    'role_wise' => 'Role Wise',
    'multiple_role_select_user' => 'Multiple Role Select User',
    'all_subscription' => 'All Subscription',
    'selected_role_user' => 'Selected Role User',
    'save_test_mail' => 'Save & Test Mail',
    'test_mail_has_been_send_successfully' => 'Test Mail has been Send successfully!',
    'test_mail' => 'Test Mail',
    'bulk_sms' => 'Bulk SMS',
    'sms_list' => 'SMS List',
    'sending' => 'Sending',
    'test_sms_has_been_send_successfully' => 'Test SMS has been Send successfully!',
    'message_to' => 'Message To',
    'create_bulk_sms' => 'Create Bulk SMS',
    'update_bulk_sms' => 'Update Bulk SMS',
    'save_test_sms' => 'Save & Test SMS',
    'test_sms' => 'Test SMS',
    'coupon_list' => 'Coupon List',
    'select_coupon_type_first' => 'Select Coupon Type First',
    'product_base' => 'Product Base',
    'order_base' => 'Order Base',
    'free_shipping' => 'Free Shipping',
    'create_coupon' => 'Create Coupon',
    'coupon_type' => 'Coupon Type',
    'add_coupon_for_free_shipping' => 'Add Coupon For Free Shipping',
    'add_coupon_based_on_order' => 'Add Coupon Based on Order',
    'add_coupon_based_on_products' => 'Add Coupon Based on Products',
    'coupon_code' => 'Coupon code',
    'maximum_discount' => 'Maximum Discount',
    'allow_multiple_buy' => 'Allow Multiple Buy',
    'minimum_shopping' => 'Minimum Shopping',
    'referral_code_list' => 'Referral Code List',
    'amount_is_getter_than_maximum_limit' => 'Amount is getter than maximum limit',
    'customer_name' => 'Customer Name',
    'create_date' => 'Create Date',
    'maximum_limit' => 'Maximum Limit',
    'subscriber' => 'Subscriber',
    'subscriber_list' => 'Subscriber List',
    'marketing' => 'Marketing',
    'flash_deals' => 'Flash Deals',
    'coupons' => 'Coupons',
    'subscribers' => 'Subscribers',
    'news_letters' => 'News Letters',
    'referral_code_setup' => 'Referral Code Setup',
    'num_of_uses' => 'Num of uses',
    'total_discount' => 'Total Discount',
    'this_item_already_added_to_list' => 'This item already added to list.',
    'marketing_campaign_planning' => 'Marketing campaign planning',
    'cool_app' => 'Cool App',
    'awesome_app' => 'Awesome App',
    'what_a_cool_app' => 'what a Cool App',
    'marketing setting' => 'marketing setting',
    'Send verify link' => 'Send verify link',
    'Verification link send successfully' => 'Verification link send successfully.',
    'giftcard' => 'Giftcard',
    'multiple_buy_limit' => 'Multiple Buy Limit',
    'merchant_coupon' => "Merchant Coupon",
    'add_coupon_for_merchant' => "Add Coupon for Merchant",
    "Plan Price" => "Plan Price"
];
